@@ -1,7 +1,7 @@
 #' @include get_internal_data.R
 #' @include M_value.R
 #' @include get_contribution.R
-NULL
+#' @include mutual_inv.R
 #' @import data.table
 #' @import parallel
 #' @import stats
@@ -14,10 +14,17 @@ M <- function(data, group, unit, by = NULL, contribution.from = NULL, cores = NU
     data_by <- split(data, by = by)
 
     if (!is.null(cores)) {
-      M_list <- mclapply(X = data_by, function(d) {
-        data_tmp <- get_internal_data(data = d, vars = c(group, unit))
-        cbind(unique(d[, ..by]), M = M_value(data = data_tmp, group = group, unit = unit))
-      }, mc.cores = cores)
+      if ((tolower(Sys.info()["sysname"]) == "windows") || (cores <= 6)) {
+        M_list <- lapply(X = data_by, function(d) {
+          data_tmp <- get_internal_data(data = d, vars = c(group, unit))
+          cbind(unique(d[, ..by]), M = M_value(data = data_tmp, group = group, unit = unit))
+        })
+      } else {
+        M_list <- mclapply(X = data_by, function(d) {
+          data_tmp <- get_internal_data(data = d, vars = c(group, unit))
+          cbind(unique(d[, ..by]), M = M_value(data = data_tmp, group = group, unit = unit))
+        }, mc.cores = cores)
+      }
     } else {
       M_list <- lapply(X = data_by, function(d) {
         data_tmp <- get_internal_data(data = d, vars = c(group, unit))
@@ -48,22 +55,32 @@ M <- function(data, group, unit, by = NULL, contribution.from = NULL, cores = NU
       if (((isTRUE(contribution %in% group)) & (length(group) < 2)) | (isTRUE(contribution %in% unit)) & (length(unit) < 2))
         stop("When using option 'contribution.from' vectors 'group' or 'unit' should have length larger than one. Compute without option 'contribution.from'.")
       data_tmp <- get_internal_data(data = data, vars = c(group, unit))
-      index_total <- mutual(data = data_tmp, group = group, unit = unit)
+      index_total <- mutual_inv(data = data_tmp, group = group, unit = unit)
 
       if (!is.null(cores)) {
-        M_contribution <- mclapply(X = contribution, function(c) {
-          if (c %in% group) c_tmp <- group[!group %in% c]
-          else c_tmp <- unit[!unit %in% c]
-          data_tmp <- get_internal_data(data = data, vars = c(group, unit, c_tmp))
-          DT_res <- rev(mutual(data = data_tmp, group = group, unit = unit, within = c_tmp))
-          DT_res[, 1]
-        }, mc.cores = cores)
+        if ((tolower(Sys.info()["sysname"]) == "windows") || (cores <= 6)) {
+          M_contribution <- lapply(X = contribution, function(c) {
+            if (c %in% group) c_tmp <- group[!group %in% c]
+            else c_tmp <- unit[!unit %in% c]
+            data_tmp <- get_internal_data(data = data, vars = c(group, unit, c_tmp))
+            DT_res <- rev(mutual_inv(data = data_tmp, group = group, unit = unit, within = c_tmp))
+            DT_res[, 1]
+          })
+        } else {
+          M_contribution <- mclapply(X = contribution, function(c) {
+            if (c %in% group) c_tmp <- group[!group %in% c]
+            else c_tmp <- unit[!unit %in% c]
+            data_tmp <- get_internal_data(data = data, vars = c(group, unit, c_tmp))
+            DT_res <- rev(mutual_inv(data = data_tmp, group = group, unit = unit, within = c_tmp))
+            DT_res[, 1]
+          }, mc.cores = cores)
+        }
       } else {
         M_contribution <- lapply(X = contribution, function(c) {
           if (c %in% group) c_tmp <- group[!group %in% c]
           else c_tmp <- unit[!unit %in% c]
           data_tmp <- get_internal_data(data = data, vars = c(group, unit, c_tmp))
-          DT_res <- rev(mutual(data = data_tmp, group = group, unit = unit, within = c_tmp))
+          DT_res <- rev(mutual_inv(data = data_tmp, group = group, unit = unit, within = c_tmp))
           DT_res[, 1]
         })
       }
